local mod = ...



-- Job: Rabbit -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "JOB",
	Id = "JOB_MONASTICLIFE_RABBIT",
	JobName = "JOB_MONASTICLIFE_RABBIT_NAME",
	JobDescription = "JOB_MONASTICLIFE_RABBIT_DESC",
	IsLockedByDefault = true,
	DefaultBehavior = "BEHAVIOR_GATHER",
	UseWorkplaceBehavior = true,
    ProductionDelay = 1, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		RightHandObject = {
			DataType = "HAND_OBJECT",
			Model = "PREFAB_TOOL_HERBALIST_SICKLE",
		},
        WalkAnimation = "WALKING",
		IdleAnimation = "FORESTER",
	},
})

mod:overrideAsset({
    Id = "MONK",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_RABBIT",
    },
})

mod:overrideAsset({
    Id = "MONK_PRIOR",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_MONASTICLIFE_RABBIT",
    },
})



-- Building Function: Rabbit --------------------------------------------------------------------------------------------
mod:registerAsset({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_MONASTICLIFE_RABBIT",
    Name = "BUILDING_FUNCTION_MONASTICLIFE_RABBIT_NAME",
    IsPrivate = true,
    WorkerCapacity = 1,
    RelatedJob = {
        Job = "JOB_MONASTICLIFE_RABBIT",
        Behavior = "BEHAVIOR_GATHER",
    },
    InputInventoryCapacity = {
    },
    ResourceListNeeded = {
        { Resource = "RESOURCE_GRASS", Quantity = 1 },
    },
    ResourceProduced = {
        { Resource = "RESOURCE_RABBIT", Quantity = 2 },
        { Resource = "RESOURCE_DUNG", Quantity = 1 },
    },
})



-- Building Part: Rabbit -------------------------------------------------------------------------------------

-- Assets
mod:registerAssetId("models/Monastery1.fbx/Prefab/Rabbit.Part.001", "PREFAB_MONASTICLIFE_RABBIT1" )
mod:registerAssetId("models/Monastery1.fbx/Prefab/Rabbit.Part.001.Constr", "PREFAB_MONASTICLIFE_RABBIT1_CONSTR" )

-- Grounding
mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Rabbit.Part.001/Basket.001/", { DataType = "COMP_GROUNDED" } )
for i=1, 20 do
    mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Rabbit.Part.001/Attach_Minor." .. string.sub("000" .. i + 10, -3), { DataType = "COMP_GROUNDED" })
end

-- Material
mod:registerAssetId("models/Monastery1.fbx/Materials/Material.Net1", "MATERIAL_MONASTICLIFE_NET1")
mod:overrideAsset({
    Id = "MATERIAL_MONASTICLIFE_NET1",
    HasAlphaTest = true,
})

-- Resource Container and Plantable
for i=1, 20 do
    -- mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Rabbit.Part.001/Grass." .. string.sub("000" .. i, -3), { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 0.2 })
    mod:registerPrefabComponent("models/Monastery1.fbx/Prefab/Rabbit.Part.001/Grass." .. string.sub("000" .. i, -3), {
		DataType = "COMP_RESOURCE_CONTAINER",
		ResourceData = "RESOURCE_GRASS",
		IsReplenishable = true,
		ReplenishDurationInDays = 2,
		ReplenishQuantity = 1,
		ReplenishedMaterial = nil,
		DepletedMaterial = nil,
		ResourceValue = 0.25, -- how many are gathered with each pick
		AvailableQuantity = 1, -- maximum container stock
		Radius = 2.00, -- distance from container that the villager will stand to pick
		IsDestroyWhenEmpty = false,
		HasMaximumWorkstation = false,
	})
end

-- Part
local poly1 = { -- y, x     Facing x in Blender: y increases going left, x increases going down
	{ -0.1, 2.9 },
	{ 2.1, 3.1 },
	{ 3.1, 1.9 },
	{ 3.1, -1.7 },
	{ 2.1, -3.0 },
	{ -3.6, -1.4 },
	{ -3.2, 0.7 },
	{ -2.3, 2.9 },
	{ -2.1, 3.1 },
	{ -0.9, 2.9 },
}

mod:registerAsset({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_MONASTICLIFE_RABBIT1",
	Name = "BUILDING_PART_MONASTICLIFE_RABBIT_NAME",
	AssetBuildingFunction = "BUILDING_FUNCTION_MONASTICLIFE_RABBIT",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_MONASTICLIFE_RABBIT1",
        MiniatureConfig = {
            ClipUnderGround = true,
            GroupHeight = 0,
            CameraPosition = { 0, 0, 0 },
            OrientationOffset = 0,
            CameraPitchOffset = 0.0
        },
	},
    ConstructionVisual = "PREFAB_MONASTICLIFE_RABBIT1_CONSTR",
	BuildingZone = {
        ZoneEntryList = {
            {
                Polygon = poly1,
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true },
			},
        },
	},
    Cost = {
        BuildRightTaxes = {
            { Resource = "GOLD_COINS", Quantity = 40 }
        },
        UpkeepCost = {
            { Resource = "GOLD_COINS", Quantity = 15 }
        },
        ResourceNeededList = {
            {
                { Resource = "POLISHED_STONE", Quantity = 10 },
                { Resource = "PLANK", Quantity = 10 },
                { Resource = "TOOL", Quantity = 2 },
            },
        },
    },
})

